import optuna
import os
import sys
import argparse
import importlib

env_path = os.path.join(os.path.dirname(__file__), '..')
if env_path not in sys.path:
    sys.path.append(env_path)

from run_adimp import run_adimp
from pytracking.analysis.plot_results import individual_results
from pytracking.evaluation import Tracker, get_dataset, trackerlist




N_Trials = 30
dataset_name = 'uavocc'
tracker_name = 'adimp'
param_file = 'adimp'



def eval(dataset_name):
    trackers = []
    trackers.extend(trackerlist('adimp', 'adimp50', [0], 'ADiMP50'))
    dataset = get_dataset(dataset_name)
    result_tensor = individual_results(trackers, dataset, dataset_name, merge_results=True, plot_types=('success', 'prec', 'norm_prec'))
    return result_tensor['AUC'].item()


def get_parameters(tracker_name,param_file):
        """Get parameters."""
        param_module = importlib.import_module('pytracking.parameter.{}.{}'.format(tracker_name, param_file))
        params = param_module.parameters()
        return params

def run_and_eval(param):
    os.system('rm pytracking/tracking_results/adimp/adimp/*.txt')
    track_params = get_parameters(tracker_name,param_file )

    track_params.gamma = param['gamma']
    track_params.online_lr = param['online_lr']

    #track_params.orig_wt = param['orig_wt']


    run_adimp(tracker_name,param_file, dataset_name,track_params)

    os.system('cp pytracking/tracking_results/adimp/adimp/*.txt  pytracking/tracking_results/adimp/adimp50_000/')
    os.system('rm pytracking/tracking_results/adimp/adimp/*.txt')
    eval_pckl_sckpt = 'rm pytracking/result_plots/'+ dataset_name + '/eval_data.pkl'
    os.system(eval_pckl_sckpt)

    
    accuracy = eval(dataset_name)
    print(track_params.gamma)
    print(track_params.online_lr)
    print(accuracy)

    os.system('rm pytracking/tracking_results/adimp/adimp50_000/*.txt')
    
    return accuracy




def objective(trial):
     
    params = {
              'online_lr': trial.suggest_uniform('online_lr',0.008,0.04),
              #'Nsamples_CD': trial.suggest_int('Nsamples_CD', 6, 10),
              'gamma': trial.suggest_uniform('gamma', 1.1, 1.4)
             }

   
    
    accuracy = run_and_eval(params)


    return accuracy


study = optuna.create_study(direction="maximize", sampler=optuna.samplers.TPESampler())
study.optimize(objective, n_trials=N_Trials)

best_trial = study.best_trial

for key, value in best_trial.params.items():
    print("{}: {}".format(key, value))
