import os
import sys
import argparse

env_path = os.path.join(os.path.dirname(__file__), '..')
if env_path not in sys.path:
    sys.path.append(env_path)

from pytracking.evaluation import Tracker
from pytracking.evaluation.running import run_dataset
from pytracking.evaluation import get_dataset
def run_tracker(tracker_name, tracker_param, run_id=None, dataset_name='otb', sequence=None, debug=0, threads=0,
                visdom_info=None, pre_loaded_param = None):
    """Run tracker on sequence or dataset.
    args:
        tracker_name: Name of tracking method.
        tracker_param: Name of parameter file.
        run_id: The run id.
        dataset_name: Name of dataset (otb, nfs, uav, tpl, vot, tn, gott, gotv, lasot).
        sequence: Sequence number or name.
        debug: Debug level.
        threads: Number of threads.
        visdom_info: Dict optionally containing 'use_visdom', 'server' and 'port' for Visdom visualization.
    """

    visdom_info = {} if visdom_info is None else visdom_info

    dataset = get_dataset(dataset_name)

    if sequence is not None:
        dataset = [dataset[sequence]]

    trackers = [Tracker(tracker_name, tracker_param, run_id,pre_loaded_param=pre_loaded_param)]

    run_dataset(dataset, trackers, debug, threads, visdom_info=visdom_info)





def run_adimp(tracker_name, param_file,dataset_name, params):

    run_tracker(tracker_name, param_file, None, dataset_name, None, 0,
                0, {'use_visdom':False, 'server': '127.0.0.1', 'port': 8097},pre_loaded_param=params)


